#ifndef lint
static char const 
yyrcsid[] = "$FreeBSD: src/usr.bin/yacc/skeleton.c,v 1.28 2000/01/17 02:04:06 bde Exp $";
#endif
#include <stdlib.h>
#define YYBYACC 1
#define YYMAJOR 1
#define YYMINOR 9
#define YYLEX yylex()
#define YYEMPTY -1
#define yyclearin (yychar=(YYEMPTY))
#define yyerrok (yyerrflag=0)
#define YYRECOVERING() (yyerrflag!=0)
static int yygrowstack();
#define YYPREFIX "yy"
#line 2 "ocl.y"
/***************************************************************************************
 * This is the second version of the ocl parser
 * Some of the production rules defined in the specification are syntactically
 * ambiguouts, so disambiguating rules have also been defined in the spicification.
 * But those rules may be based on the UML model to which the OCL expression
 * is parsed, thus the UML model must be available when an OCL expression is
 * parsed using those production rules.
 * At the time being, I couldn't figure out how to access the UML model info.
 * So I will change the production rules quite a bit, which means at the end
 * of this first parse, an instance of the abstract syntax could not be build.
 * My final option may be the grammar given in OCL1.4 specification. But I won't
 * chose it as long as I have another choice.
 *
 ***************************************************************************************
 *
 * Notes:
 * 1.The concrete syntax in the OCL2.0 specification does not define
 *   IntegerLiteralExp, RealLiteralExp, StringLiteralExp and BooleanLiteralExp
 *   for internationalization, I make my own decisions here, but they may be
 *   modified later.
 * 2.In the concrete syntax, EnumLiteralExp is defined as:
 *      EnumLiteralExp ::= name '::' <String>
 *   with the disambiguating rule: the specified name must indeed reference
 *   an enumeration. Or, it will have a reduce/reduce conflict with the
 *   production rule for name.
 *   But it is not easy to checked. So, I postpone this question by modifying
 *   the rule as below:
 *       EnumLiteralExp ::= '#' name '::' <String>
 * 3.CollectionRange ::= OclExpression '..' OclExpression
 *   Since an OclExpression could be a real number, to make "1..3" parsed correctly,
 *   I decide that "1." is an illegal form of a real number.
 * 4.According to the abstract syntax, the iterator for LoopExp is mandatary.
 *   So, instead of define iterator as:
 *       iterator::= VariableDeclaration?
 *   we could have an iterator or a default iterator, but even by doing that,
 *   the '|' is mandatary, or we will end up with a shift/reduce conflict
 *   I won't use a default_iterator here.
 * 5.In a VarDeclaration, if an initExpression is given, the type must be also given.
 * 6.A referredOperation can be a relational operation, a predefined collection
 *   operation or a operation "mdlProperty" defined in the UML model by the user
 *   "Implies" is added to the "RELOP" list; "not" operation is also added
 *   Furthermore, operationCall, attributeCall and navigationCall will share the keyword
 *   mdlProperty to resolve conflicts. An attributeCall and a navigationCall will be the
 *   same at this stage without knowing the UML model.
 * 7.To parse correctly, the source of the OperationCallExp must be specified
 * 9.The unary minus is not handled at the time being
 *10.OclOperationWithStateArgument operation is not handled at the time being
 *11.The syntax of LetExp is not the same as that in the specification
 *   the semi-colon is specified in the concrete syntax but not in the examples
 *   given in the specification, but i decide to keep the semi-colon
 *12.The precedence of '^' is not given in the concrete syntax, I decide to give it
 *   the same precedence as dot and arrow.
 *   The OclMessageExp need to be studied further.
 *13.TRUE and FALSE will be defined as boolean value on the one hand;
 *   on the other hand, they will be also return from lex as tokens SYM_TRUE and SYM_FALSE
 *14.Token REJECT will be noted as SYM_REJECT, since REJECT is a lex keyword
 */

#include <Python.h>
#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include <getopt.h>
#include "util.h"
#include "absyn.h"
#include "creat_python.h"
  /*include "ocl.h" */

extern FILE *yyin, *yyout;

int lineno = 1;

string oclSrc;

extern void yyerror(char *);

#line 82 "ocl.y"
typedef union {
  int ival;
  double dval;
  string sval;
  bool bval;
  A_oclExpression oclExpression;
  A_propertyCallExp propertyCallExp;
  A_variableExp variableExp;
  A_literalExp literalExp;
  A_letExp letExp;
  A_oclMessageExp oclMessageExp;
  A_ifExp ifExp;
  A_name pathName;
  A_enumLiteralExp enumLiteralExp;
  A_collectionLiteralExp collectionLiteralExp;
  A_tupleLiteralExp tupleLiteralExp;
  A_numericLiteralExp numericLiteralExp;
  A_stringLiteralExp stringLiteralExp;
  A_booleanLiteralExp booleanLiteralExp;
  A_collectionTypeIdentifier collectionType;
  A_collectionItem collectionItem;
  A_collectionRange collectionRange;
  A_integerLiteralExp integerLiteralExp;
  A_realLiteralExp realLiteralExp;
  A_tupleLiteralExpParts tupleLiteralExpParts;
  A_variableDeclaration variableDeclaration;
  A_modelPropertyCallExp modelPropertyCallExp;
  A_loopExp loopExp;
  A_iteratorExp iteratorExp;
  A_iterateExp iterateExp;
  A_collectionOp collectionOp;
  A_operationCallExp operationCallExp;
  A_attrOrNavCallExp attrOrNavCallExp;
  A_variables vars;
  A_oclMessageArg oclMessageArg;
  A_arguments args;
} YYSTYPE;
#line 132 "y.tab.c"
#define YYERRCODE 256
#define INTEGER 257
#define REAL 258
#define QSTRING 259
#define NAMESTRING 260
#define SYM_TRUE 261
#define SYM_FALSE 262
#define SELECT 263
#define COLLECT 264
#define SYM_REJECT 265
#define FORALL 266
#define EXISTS 267
#define ISUNIQUE 268
#define SIZE 269
#define ISEMPTY 270
#define NOTEMPTY 271
#define COUNT 272
#define UNION 273
#define DIFFERENCE 274
#define NOT 275
#define INV 276
#define PRE 277
#define POST 278
#define DEF 279
#define SET 280
#define BAG 281
#define SEQUENCE 282
#define TUPLE 283
#define DCOLON 284
#define DDOT 285
#define IN 286
#define ITERATE 287
#define ATPRE 288
#define LET 289
#define IF 290
#define THEN 291
#define ELSE 292
#define ENDIF 293
#define IMPLIES 294
#define AND 295
#define OR 296
#define XOR 297
#define EQ 298
#define NOTEQ 299
#define LT 300
#define GT 301
#define LTEQ 302
#define GTEQ 303
#define PLUS 304
#define MINUS 305
#define TIMES 306
#define DIVIDES 307
#define DOT 308
#define ARROW 309
const short yylhs[] = {                                        -1,
    0,   55,   55,   56,   57,   57,   57,   57,    1,    1,
    1,    1,    1,    1,    1,   12,   17,   17,   13,   13,
   13,   13,   13,   13,   19,   20,   25,   25,   25,   28,
   28,   27,   27,   26,   26,   29,    2,   22,   22,   30,
   31,   23,   24,   24,   21,   21,   32,   32,   34,   11,
   11,   40,   40,   41,   42,   43,   43,   43,   43,   43,
   43,   43,   43,   43,   43,   43,   43,   35,   35,   36,
   33,   33,   33,   44,   18,    4,   39,   39,   45,   45,
   45,   45,   45,   45,   45,   45,   45,   45,   45,   45,
   45,   45,   45,   45,   45,   47,   47,   49,   49,    5,
   48,   48,    3,   50,   46,   14,   51,   51,   38,   37,
    6,    7,   15,   52,   52,   53,   53,   54,   54,   54,
   16,    8,    9,   10,
};
const short yylen[] = {                                         2,
    1,    0,    2,    3,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    3,    1,    1,    3,    1,    1,
    1,    1,    1,    1,    4,    4,    1,    1,    1,    0,
    1,    1,    3,    1,    1,    3,    1,    1,    1,    1,
    1,    1,    1,    1,    4,    3,    1,    3,    1,    1,
    1,    1,    1,    8,   10,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    0,    1,    1,
    5,    3,    1,    1,    1,    1,    1,    1,    3,    3,
    3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
    3,    3,    7,    5,    2,    0,    1,    0,    1,    1,
    1,    3,    1,    1,    4,    3,    2,    3,    1,    5,
    2,    3,    6,    0,    1,    1,    3,    1,    3,    1,
    7,    1,    1,    1,
};
const short yydefred[] = {                                      2,
    0,    0,    5,    6,    7,    8,    3,    0,    0,   40,
   41,   42,    0,   43,   44,    0,   27,   28,   29,    0,
    0,    0,    0,    0,    0,    9,   10,   11,   12,   13,
   14,   16,   19,   20,   21,   22,   23,   24,    0,   38,
   39,   50,   51,   52,   53,   77,   78,    0,    0,    0,
    0,   74,  109,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,   97,
    0,   18,   46,    0,   49,    0,    0,    0,    0,    0,
  106,    0,   15,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  104,    0,
   56,   57,   58,   59,   60,   61,   62,   63,   64,   65,
   66,   67,    0,    0,    0,    0,   35,    0,   31,    0,
   34,    0,   45,    0,    0,  108,   75,    0,    0,  111,
    0,    0,   25,    0,    0,    0,    0,    0,    0,   26,
    0,    0,   99,    0,   48,    0,    0,    0,    0,    0,
   69,    0,    0,    0,    0,    0,  115,    0,    0,   33,
    0,   94,    0,    0,  110,  112,    0,    0,    0,    0,
    0,    0,  113,    0,  102,   71,  121,   93,   70,    0,
    0,    0,  119,  117,    0,   54,    0,   55,
};
const short yydgoto[] = {                                       1,
  151,  127,  192,  175,  152,   91,  140,   58,  142,  178,
   26,   27,   28,   29,   30,   31,   32,  138,   33,   34,
   35,   36,   37,   38,   39,  128,  129,  130,  131,   40,
   41,   84,   85,   86,  162,  190,   53,   54,   42,   43,
   44,   45,  124,   87,   46,   47,   81,  153,  154,   48,
   56,  166,  167,  168,    2,    7,    8,
};
const short yysindex[] = {                                      0,
    0, -250,    0,    0,    0,    0,    0,  -44,  835,    0,
    0,    0, -261,    0,    0,  835,    0,    0,    0,  -92,
 -236,  835,  835, -226,  839,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  -87,    0,
    0,    0,    0,    0,    0,    0,    0, -251, -226,  -79,
 -122,    0,    0,  -21,  -19, -246,  839, -247,  464, -261,
 -235,  835,  835,  835,  835,  835,  835,  835,  835,  835,
  835,  835,  835,  835,  835, -212,  -99, -210,  835,    0,
   11,    0,    0,  -73,    0,    9,   -4, -236, -226,   15,
    0,  835,    0, -204,  990,  -62,  -62,  -62,  262,  262,
  -51,  -51,  -51,  -51,  -86,  -86,  -79,  -79,    0, -251,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,   17,   19,   21,  -90,    0,   18,    0,  -61,
    0,  835,    0, -236, -226,    0,    0, -232,  835,    0,
  839, -229,    0,   27, -236, -236,  780,  835,  835,    0,
  839,   24,    0,   29,    0, -227,  835,  641,  835,  835,
    0,   13,  -50,   20,  839,   36,    0,   37,  839,    0,
  835,    0,  835,  839,    0,    0,  839, -213,   43, -236,
  835, -226,    0,  780,    0,    0,    0,    0,    0,  -32,
  839,   48,    0,    0,  835,    0,   52,    0,
};
const short yyrindex[] = {                                      0,
    0,   96,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    1,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,   46,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,   57,    0,  137,
    0,    0,    0,    0,    0,    0, -193,    0,    0,   69,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  -26,    0,
    0,    0,    0,    0,    0,  -20,  -42, -186,    0,    0,
    0,    0,    0,    0,  989,  910,  934,  958,  689,  873,
  533,  561,  600,  628,  418,  500,  191,  225,    0,   35,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  -35,    0,  -18,    0,    0,
    0,   60,    0,    0,    0,    0,    0,    0,    0,    0,
 -190,    0,    0,  103,   45,  -16,   65,    0,    0,    0,
  -25,   68,    0,    0,    0,  -39,    0,    0,    0,   60,
    0,    0,    0,  -23,  -11,    0,    0,   71,  -34,    0,
    0,    0,    0,  -37,    0,    0, -179,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
   74,    0,    0,    0,    0,    0,    0,    0,
};
const short yygindex[] = {                                      0,
 1247,    0,  -78,  -57,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  -24, -124,    0,    0,
    0,    0,    0,    0,    0,    0,  -31,    0,    0,    0,
    0,  -14, -133,    0,  -27,    0,    0,    0,    0,    0,
    0,    0,    0,  -15,    0,    0,   12,  -48,  -36,   51,
   33,    0,  -54,    0,    0,    0,    0,
};
#define YYTABLESIZE 1442
const short yytable[] = {                                      61,
   17,   73,   83,   78,   72,   55,   76,   78,   37,   36,
  156,  161,  161,    9,   78,  100,   73,  118,  100,   72,
  118,   76,   49,   52,   82,    3,    4,    5,    6,  120,
   51,   78,  120,   60,   96,   79,   80,   88,   89,   90,
  104,   17,   78,   92,   17,    4,  189,  109,   94,  125,
  132,  133,  134,  135,  139,  143,  145,  193,  146,   17,
  147,  149,  159,  150,  137,  157,  160,  171,   17,  172,
  173,  180,   55,  181,   96,   96,  183,  182,   96,  187,
  184,   73,   73,  188,   72,   72,   76,   76,  196,   37,
   36,  195,  198,   96,   17,    1,   96,  122,   30,  107,
   98,  123,  105,   68,   47,  114,   32,   68,  101,   17,
  137,  116,   17,  124,  103,  186,  197,  170,  163,  155,
  136,  144,  185,  179,   17,   17,  110,   17,   96,  194,
    0,    0,    0,    0,    0,    0,   95,   52,    0,    0,
    0,    0,    0,  105,    0,    0,  105,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  137,   96,   96,
    0,  105,   17,  111,  112,  113,  114,  115,  116,  117,
  118,  119,  120,  121,  122,    0,    0,   95,    0,    0,
   95,    0,    0,    0,    0,    0,    0,  123,    0,    0,
   81,    0,   17,   17,  148,   95,  105,    0,    0,    0,
    0,    0,    0,   62,   63,   64,   65,   66,   67,   68,
   69,   70,   71,   72,   73,   74,   75,   76,   77,   74,
   75,   76,   77,    0,   82,    0,  105,  105,   76,   77,
    0,   81,    0,    0,   81,   66,   67,   68,   69,   70,
   71,   72,   73,   74,   75,   76,   77,    0,    0,   81,
    0,    0,   72,   73,   74,   75,   76,   77,    0,    0,
   95,   95,    0,    0,    0,   82,    0,    0,   82,    0,
    0,    0,    0,    0,    0,    0,   17,   17,   17,   17,
    0,    0,    0,   82,    0,   17,    0,    0,  104,    0,
    0,   17,   17,   17,   17,   17,   17,   17,   17,   17,
   17,   17,   17,   17,   17,   17,   17,   17,   17,   17,
   96,   96,   96,   96,   81,   81,    0,    0,    0,   96,
    0,    4,    4,    4,    4,   96,   96,   96,   96,   96,
   96,   96,   96,   96,   96,   96,   96,   96,   96,   96,
   96,   96,   96,   96,   17,   17,   17,   17,   82,   82,
    0,    0,    0,   17,    0,   78,    0,    0,    0,   17,
   17,   17,   17,   17,   17,   17,   17,   17,   17,   17,
   17,   17,   17,   17,   17,   17,   17,   17,  105,  105,
  105,  105,    0,    0,    0,    0,    0,  105,    0,    0,
    0,    0,    0,  105,  105,  105,  105,  105,  105,  105,
  105,  105,  105,  105,  105,  105,  105,  105,  105,  105,
  105,  105,   95,   95,   95,   95,    0,   79,    0,    0,
    0,   95,    0,    0,    0,    0,    0,   95,   95,   95,
   95,   95,   95,   95,   95,   95,   95,   95,   95,   95,
   95,   95,   95,   95,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,   79,    0,
    0,   79,    0,    0,    0,    0,   81,   81,   81,   81,
    0,    0,    0,    0,    0,   81,   79,    0,    0,    0,
    0,   81,   81,   81,   81,   81,   81,   81,   81,   81,
   81,   81,   81,   81,   81,   81,   81,   81,    0,   80,
   82,   82,   82,   82,   93,    0,    0,    0,    0,   82,
    0,    0,    0,    0,    0,   82,   82,   82,   82,   82,
   82,   82,   82,   82,   82,   82,   82,   82,   82,   82,
   82,   82,   90,    0,    0,    0,    0,    0,    0,    0,
   80,   79,   79,   80,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,   78,   80,    0,
   91,   68,   69,   70,   71,   72,   73,   74,   75,   76,
   77,    0,    0,   90,    0,    0,   90,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,   90,    0,    0,    0,    0,    0,    0,    0,   88,
    0,   91,    0,    0,   91,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,   91,
    0,    0,    0,   80,   80,    0,    0,   89,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
   88,    0,    0,   88,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,   90,   90,   88,    0,
    0,    0,    0,    0,    0,    0,    0,    0,   89,    0,
    0,   89,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  176,    0,    0,   91,   91,   89,    0,   86,    0,
    0,    0,    0,   79,   79,   79,   79,    0,    0,    0,
    0,    0,   79,    0,    0,    0,    0,    0,   79,   79,
   79,   79,   79,   79,   79,   79,   79,   79,   79,   79,
   79,   79,   79,   88,   88,    0,    0,    0,    0,   86,
    0,    0,   86,    0,   78,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,   86,    0,    0,
    0,   89,   89,    0,    0,    0,    0,   62,   63,   64,
   65,   66,   67,   68,   69,   70,   71,   72,   73,   74,
   75,   76,   77,    0,    0,   80,   80,   80,   80,    0,
    0,    0,    0,    0,   80,    0,    0,    0,    0,    0,
   80,   80,   80,   80,   80,   80,   80,   80,   80,   80,
   80,   80,   80,   80,   80,    0,    0,    0,   90,   90,
   90,   90,   86,   86,   24,    0,    0,   90,    0,   23,
    0,    0,    0,   90,   90,   90,   90,   90,   90,   90,
   90,   90,   90,   90,   90,   90,   91,   91,   91,   91,
    0,    0,  164,    0,    0,   91,    0,    0,    0,    0,
    0,   91,   91,   91,   91,   91,   91,   91,   91,   91,
   91,   91,   91,   91,    0,    0,    0,    0,    0,   24,
    0,    0,   87,    0,   23,   88,   88,   88,   88,    0,
    0,    0,    0,    0,   88,    0,    0,    0,    0,    0,
   88,   88,   88,   88,   88,   88,   88,   88,   88,   88,
   88,   88,   88,   89,   89,   89,   89,    0,    0,   83,
    0,    0,   89,   87,    0,    0,   87,    0,   89,   89,
   89,   89,   89,   89,   89,   89,   89,   89,   89,   89,
   89,   87,   78,   84,   62,   63,   64,   65,   66,   67,
   68,   69,   70,   71,   72,   73,   74,   75,   76,   77,
   83,    0,    0,   83,    0,    0,    0,   85,    0,    0,
    0,    0,    0,    0,   86,   86,   86,   86,   83,    0,
    0,    0,    0,   86,   84,    0,    0,   84,    0,   86,
   86,   86,   86,   86,   86,   86,   86,   86,   92,    0,
    0,    0,   84,    0,    0,    0,   87,   87,   85,    0,
    0,   85,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,   85,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,   92,
    0,    0,   92,   83,   83,    0,   10,   11,   12,   13,
   14,   15,    0,    0,    0,    0,    0,   92,    0,    0,
    0,    0,    0,    0,   16,    0,    0,   84,   84,   17,
   18,   19,   20,    0,    0,    0,    0,    0,   21,   22,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,   85,   85,   78,    0,    0,    0,    0,    0,    0,
    0,   10,   11,   12,   13,   14,   15,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,   16,
    0,    0,   92,   92,   17,   18,   19,   20,    0,    0,
    0,    0,    0,   21,   22,    0,    0,    0,    0,    0,
    0,    0,   62,   63,   64,   65,   66,   67,   68,   69,
   70,   71,   72,   73,   74,   75,   76,   77,   87,   87,
   87,   87,    0,    0,    0,    0,    0,   87,    0,    0,
    0,    0,    0,   87,   87,   87,   87,   87,   87,   87,
   87,   87,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,   83,   83,   83,   83,    0,
    0,    0,    0,    0,   83,    0,    0,    0,    0,    0,
   83,   83,   83,   83,   83,   83,   83,    0,    0,   84,
   84,   84,   84,    0,    0,    0,    0,    0,   84,    0,
    0,    0,    0,    0,   84,   84,   84,   84,   84,   84,
   84,    0,    0,   85,   85,   85,   85,    0,    0,    0,
    0,    0,   85,    0,    0,    0,    0,    0,   85,   85,
   85,   85,   85,   85,   85,   25,    0,    0,    0,    0,
    0,    0,   50,    0,   92,   92,   92,   92,   57,   59,
    0,    0,    0,   92,    0,    0,    0,    0,    0,   92,
   92,   92,   92,    0,   63,   64,   65,   66,   67,   68,
   69,   70,   71,   72,   73,   74,   75,   76,   77,    0,
    0,    0,    0,    0,    0,    0,    0,    0,   95,   96,
   97,   98,   99,  100,  101,  102,  103,  104,  105,  106,
  107,  108,    0,    0,    0,  126,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  141,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  158,    0,    0,    0,    0,
    0,    0,    0,  165,  169,  126,    0,    0,    0,    0,
    0,    0,    0,  174,    0,  177,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  174,
    0,    0,    0,    0,    0,    0,    0,  191,    0,    0,
  165,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  191,
};
const short yycheck[] = {                                      24,
    0,   44,  125,   94,   44,   21,   44,   94,   44,   44,
  135,  145,  146,   58,   94,   41,   59,   41,   44,   59,
   44,   59,  284,  260,   49,  276,  277,  278,  279,   41,
  123,   94,   44,  260,    0,  123,  288,   59,   58,  286,
   40,   41,   94,  291,   44,    0,  180,  260,  284,  260,
   40,  125,   44,   58,   40,  260,   40,  182,   40,   59,
   40,   44,  292,  125,   89,  298,   40,   44,    0,   41,
  298,   59,   88,  124,   40,   41,   41,   58,   44,  293,
   44,  124,  125,   41,  124,  125,  124,  125,   41,  125,
  125,  124,   41,   59,   94,    0,   40,  291,  125,  286,
   41,  292,    0,   59,  125,   41,  125,  124,   41,   41,
  135,   41,   44,  293,   41,  173,  195,  149,  146,  134,
   88,  110,  171,  160,  124,  125,   76,   59,   94,  184,
   -1,   -1,   -1,   -1,   -1,   -1,    0,  260,   -1,   -1,
   -1,   -1,   -1,   41,   -1,   -1,   44,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  182,  124,  125,
   -1,   59,   94,  263,  264,  265,  266,  267,  268,  269,
  270,  271,  272,  273,  274,   -1,   -1,   41,   -1,   -1,
   44,   -1,   -1,   -1,   -1,   -1,   -1,  287,   -1,   -1,
    0,   -1,  124,  125,  285,   59,   94,   -1,   -1,   -1,
   -1,   -1,   -1,  294,  295,  296,  297,  298,  299,  300,
  301,  302,  303,  304,  305,  306,  307,  308,  309,  306,
  307,  308,  309,   -1,    0,   -1,  124,  125,  308,  309,
   -1,   41,   -1,   -1,   44,  298,  299,  300,  301,  302,
  303,  304,  305,  306,  307,  308,  309,   -1,   -1,   59,
   -1,   -1,  304,  305,  306,  307,  308,  309,   -1,   -1,
  124,  125,   -1,   -1,   -1,   41,   -1,   -1,   44,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  276,  277,  278,  279,
   -1,   -1,   -1,   59,   -1,  285,   -1,   -1,  288,   -1,
   -1,  291,  292,  293,  294,  295,  296,  297,  298,  299,
  300,  301,  302,  303,  304,  305,  306,  307,  308,  309,
  276,  277,  278,  279,  124,  125,   -1,   -1,   -1,  285,
   -1,  276,  277,  278,  279,  291,  292,  293,  294,  295,
  296,  297,  298,  299,  300,  301,  302,  303,  304,  305,
  306,  307,  308,  309,  276,  277,  278,  279,  124,  125,
   -1,   -1,   -1,  285,   -1,   94,   -1,   -1,   -1,  291,
  292,  293,  294,  295,  296,  297,  298,  299,  300,  301,
  302,  303,  304,  305,  306,  307,  308,  309,  276,  277,
  278,  279,   -1,   -1,   -1,   -1,   -1,  285,   -1,   -1,
   -1,   -1,   -1,  291,  292,  293,  294,  295,  296,  297,
  298,  299,  300,  301,  302,  303,  304,  305,  306,  307,
  308,  309,  276,  277,  278,  279,   -1,    0,   -1,   -1,
   -1,  285,   -1,   -1,   -1,   -1,   -1,  291,  292,  293,
  294,  295,  296,  297,  298,  299,  300,  301,  302,  303,
  304,  305,  306,  307,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   41,   -1,
   -1,   44,   -1,   -1,   -1,   -1,  276,  277,  278,  279,
   -1,   -1,   -1,   -1,   -1,  285,   59,   -1,   -1,   -1,
   -1,  291,  292,  293,  294,  295,  296,  297,  298,  299,
  300,  301,  302,  303,  304,  305,  306,  307,   -1,    0,
  276,  277,  278,  279,   41,   -1,   -1,   -1,   -1,  285,
   -1,   -1,   -1,   -1,   -1,  291,  292,  293,  294,  295,
  296,  297,  298,  299,  300,  301,  302,  303,  304,  305,
  306,  307,    0,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   41,  124,  125,   44,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   94,   59,   -1,
    0,  300,  301,  302,  303,  304,  305,  306,  307,  308,
  309,   -1,   -1,   41,   -1,   -1,   44,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   59,   -1,   -1,   -1,   -1,   -1,   -1,   -1,    0,
   -1,   41,   -1,   -1,   44,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   59,
   -1,   -1,   -1,  124,  125,   -1,   -1,    0,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   41,   -1,   -1,   44,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  124,  125,   59,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   41,   -1,
   -1,   44,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   41,   -1,   -1,  124,  125,   59,   -1,    0,   -1,
   -1,   -1,   -1,  276,  277,  278,  279,   -1,   -1,   -1,
   -1,   -1,  285,   -1,   -1,   -1,   -1,   -1,  291,  292,
  293,  294,  295,  296,  297,  298,  299,  300,  301,  302,
  303,  304,  305,  124,  125,   -1,   -1,   -1,   -1,   41,
   -1,   -1,   44,   -1,   94,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   59,   -1,   -1,
   -1,  124,  125,   -1,   -1,   -1,   -1,  294,  295,  296,
  297,  298,  299,  300,  301,  302,  303,  304,  305,  306,
  307,  308,  309,   -1,   -1,  276,  277,  278,  279,   -1,
   -1,   -1,   -1,   -1,  285,   -1,   -1,   -1,   -1,   -1,
  291,  292,  293,  294,  295,  296,  297,  298,  299,  300,
  301,  302,  303,  304,  305,   -1,   -1,   -1,  276,  277,
  278,  279,  124,  125,   35,   -1,   -1,  285,   -1,   40,
   -1,   -1,   -1,  291,  292,  293,  294,  295,  296,  297,
  298,  299,  300,  301,  302,  303,  276,  277,  278,  279,
   -1,   -1,   63,   -1,   -1,  285,   -1,   -1,   -1,   -1,
   -1,  291,  292,  293,  294,  295,  296,  297,  298,  299,
  300,  301,  302,  303,   -1,   -1,   -1,   -1,   -1,   35,
   -1,   -1,    0,   -1,   40,  276,  277,  278,  279,   -1,
   -1,   -1,   -1,   -1,  285,   -1,   -1,   -1,   -1,   -1,
  291,  292,  293,  294,  295,  296,  297,  298,  299,  300,
  301,  302,  303,  276,  277,  278,  279,   -1,   -1,    0,
   -1,   -1,  285,   41,   -1,   -1,   44,   -1,  291,  292,
  293,  294,  295,  296,  297,  298,  299,  300,  301,  302,
  303,   59,   94,    0,  294,  295,  296,  297,  298,  299,
  300,  301,  302,  303,  304,  305,  306,  307,  308,  309,
   41,   -1,   -1,   44,   -1,   -1,   -1,    0,   -1,   -1,
   -1,   -1,   -1,   -1,  276,  277,  278,  279,   59,   -1,
   -1,   -1,   -1,  285,   41,   -1,   -1,   44,   -1,  291,
  292,  293,  294,  295,  296,  297,  298,  299,    0,   -1,
   -1,   -1,   59,   -1,   -1,   -1,  124,  125,   41,   -1,
   -1,   44,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   59,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   41,
   -1,   -1,   44,  124,  125,   -1,  257,  258,  259,  260,
  261,  262,   -1,   -1,   -1,   -1,   -1,   59,   -1,   -1,
   -1,   -1,   -1,   -1,  275,   -1,   -1,  124,  125,  280,
  281,  282,  283,   -1,   -1,   -1,   -1,   -1,  289,  290,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  124,  125,   94,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  257,  258,  259,  260,  261,  262,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  275,
   -1,   -1,  124,  125,  280,  281,  282,  283,   -1,   -1,
   -1,   -1,   -1,  289,  290,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  294,  295,  296,  297,  298,  299,  300,  301,
  302,  303,  304,  305,  306,  307,  308,  309,  276,  277,
  278,  279,   -1,   -1,   -1,   -1,   -1,  285,   -1,   -1,
   -1,   -1,   -1,  291,  292,  293,  294,  295,  296,  297,
  298,  299,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  276,  277,  278,  279,   -1,
   -1,   -1,   -1,   -1,  285,   -1,   -1,   -1,   -1,   -1,
  291,  292,  293,  294,  295,  296,  297,   -1,   -1,  276,
  277,  278,  279,   -1,   -1,   -1,   -1,   -1,  285,   -1,
   -1,   -1,   -1,   -1,  291,  292,  293,  294,  295,  296,
  297,   -1,   -1,  276,  277,  278,  279,   -1,   -1,   -1,
   -1,   -1,  285,   -1,   -1,   -1,   -1,   -1,  291,  292,
  293,  294,  295,  296,  297,    9,   -1,   -1,   -1,   -1,
   -1,   -1,   16,   -1,  276,  277,  278,  279,   22,   23,
   -1,   -1,   -1,  285,   -1,   -1,   -1,   -1,   -1,  291,
  292,  293,  294,   -1,  295,  296,  297,  298,  299,  300,
  301,  302,  303,  304,  305,  306,  307,  308,  309,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   62,   63,
   64,   65,   66,   67,   68,   69,   70,   71,   72,   73,
   74,   75,   -1,   -1,   -1,   79,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   92,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  139,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  147,  148,  149,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  157,   -1,  159,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  173,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  181,   -1,   -1,
  184,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  195,
};
#define YYFINAL 1
#ifndef YYDEBUG
#define YYDEBUG 0
#endif
#define YYMAXTOKEN 309
#if YYDEBUG
const char * const yyname[] = {
"end-of-file",0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,"'#'",0,0,0,0,"'('","')'",0,0,"','",0,0,0,0,0,0,0,0,0,0,0,0,0,"':'","';'",0,0,
0,"'?'",0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,"'^'",0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,"'{'","'|'","'}'",0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,"INTEGER","REAL","QSTRING","NAMESTRING","SYM_TRUE","SYM_FALSE",
"SELECT","COLLECT","SYM_REJECT","FORALL","EXISTS","ISUNIQUE","SIZE","ISEMPTY",
"NOTEMPTY","COUNT","UNION","DIFFERENCE","NOT","INV","PRE","POST","DEF","SET",
"BAG","SEQUENCE","TUPLE","DCOLON","DDOT","IN","ITERATE","ATPRE","LET","IF",
"THEN","ELSE","ENDIF","IMPLIES","AND","OR","XOR","EQ","NOTEQ","LT","GT","LTEQ",
"GTEQ","PLUS","MINUS","TIMES","DIVIDES","DOT","ARROW",
};
const char * const yyrule[] = {
"$accept : start",
"start : OclConstraints",
"OclConstraints :",
"OclConstraints : OclConstraints OclConstraint",
"OclConstraint : constraintType ':' OclExpression",
"constraintType : INV",
"constraintType : PRE",
"constraintType : POST",
"constraintType : DEF",
"OclExpression : PropertyCallExp",
"OclExpression : VariableExp",
"OclExpression : LiteralExp",
"OclExpression : LetExp",
"OclExpression : OclMessageExp",
"OclExpression : IfExp",
"OclExpression : '(' OclExpression ')'",
"VariableExp : name",
"name : NAMESTRING",
"name : NAMESTRING DCOLON name",
"LiteralExp : EnumLiteralExp",
"LiteralExp : CollectionLiteralExp",
"LiteralExp : TupleLiteralExp",
"LiteralExp : NumericLiteralExp",
"LiteralExp : StringLiteralExp",
"LiteralExp : BooleanLiteralExp",
"EnumLiteralExp : '#' name DCOLON NAMESTRING",
"CollectionLiteralExp : CollectionTypeIdentifier '{' CollectionItemsPart '}'",
"CollectionTypeIdentifier : SET",
"CollectionTypeIdentifier : BAG",
"CollectionTypeIdentifier : SEQUENCE",
"CollectionItemsPart :",
"CollectionItemsPart : CollectionItems",
"CollectionItems : CollectionItem",
"CollectionItems : CollectionItem ',' CollectionItems",
"CollectionItem : CollectionRange",
"CollectionItem : individualItem",
"CollectionRange : OclExpression DDOT OclExpression",
"individualItem : OclExpression",
"NumericLiteralExp : IntegerLiteralExp",
"NumericLiteralExp : RealLiteralExp",
"IntegerLiteralExp : INTEGER",
"RealLiteralExp : REAL",
"StringLiteralExp : QSTRING",
"BooleanLiteralExp : SYM_TRUE",
"BooleanLiteralExp : SYM_FALSE",
"TupleLiteralExp : TUPLE '{' TupleLiteralExpParts '}'",
"TupleLiteralExp : TUPLE '{' '}'",
"TupleLiteralExpParts : TupleLiteralExpPart",
"TupleLiteralExpParts : TupleLiteralExpPart ',' TupleLiteralExpParts",
"TupleLiteralExpPart : VariableDeclaration",
"PropertyCallExp : ModelPropertyCallExp",
"PropertyCallExp : LoopExp",
"LoopExp : IteratorExp",
"LoopExp : IterateExp",
"IteratorExp : OclExpression ARROW colop '(' iterator '|' body ')'",
"IterateExp : OclExpression ARROW ITERATE '(' iterator ';' result '|' body ')'",
"colop : SELECT",
"colop : COLLECT",
"colop : SYM_REJECT",
"colop : FORALL",
"colop : EXISTS",
"colop : ISUNIQUE",
"colop : SIZE",
"colop : ISEMPTY",
"colop : NOTEMPTY",
"colop : COUNT",
"colop : UNION",
"colop : DIFFERENCE",
"iterator :",
"iterator : VariableDeclaration",
"result : VariableDeclaration",
"VariableDeclaration : varName ':' type EQ initExpression",
"VariableDeclaration : varName ':' type",
"VariableDeclaration : varName",
"varName : NAMESTRING",
"type : name",
"initExpression : OclExpression",
"ModelPropertyCallExp : OperationCallExp",
"ModelPropertyCallExp : AttrOrNavCallExp",
"OperationCallExp : OclExpression PLUS OclExpression",
"OperationCallExp : OclExpression MINUS OclExpression",
"OperationCallExp : OclExpression TIMES OclExpression",
"OperationCallExp : OclExpression DIVIDES OclExpression",
"OperationCallExp : OclExpression AND OclExpression",
"OperationCallExp : OclExpression OR OclExpression",
"OperationCallExp : OclExpression XOR OclExpression",
"OperationCallExp : OclExpression EQ OclExpression",
"OperationCallExp : OclExpression NOTEQ OclExpression",
"OperationCallExp : OclExpression LTEQ OclExpression",
"OperationCallExp : OclExpression GTEQ OclExpression",
"OperationCallExp : OclExpression LT OclExpression",
"OperationCallExp : OclExpression GT OclExpression",
"OperationCallExp : OclExpression IMPLIES OclExpression",
"OperationCallExp : OclExpression DOT mdlProperty timeExpr '(' argumentsOrEmpty ')'",
"OperationCallExp : mdlProperty timeExpr '(' argumentsOrEmpty ')'",
"OperationCallExp : NOT OclExpression",
"timeExpr :",
"timeExpr : ATPRE",
"argumentsOrEmpty :",
"argumentsOrEmpty : arguments",
"argument : OclExpression",
"arguments : argument",
"arguments : argument ',' arguments",
"body : OclExpression",
"mdlProperty : NAMESTRING",
"AttrOrNavCallExp : OclExpression DOT mdlProperty timeExpr",
"LetExp : LET variables LetExpSub",
"variables : variable ';'",
"variables : variable ';' variables",
"variable : variableDeclarationInLetExp",
"variableDeclarationInLetExp : varName ':' type EQ initExpression",
"LetExpSub : IN scope",
"scope : '(' OclExpression ')'",
"OclMessageExp : OclExpression '^' NAMESTRING '(' OclMsgArgOrNull ')'",
"OclMsgArgOrNull :",
"OclMsgArgOrNull : OclMessageArgs",
"OclMessageArgs : OclMessageArg",
"OclMessageArgs : OclMessageArg ',' OclMessageArgs",
"OclMessageArg : '?'",
"OclMessageArg : '?' ':' type",
"OclMessageArg : OclExpression",
"IfExp : IF condition THEN thenExpression ELSE elseExpression ENDIF",
"condition : OclExpression",
"thenExpression : OclExpression",
"elseExpression : OclExpression",
};
#endif
#if YYDEBUG
#include <stdio.h>
#endif
#ifdef YYSTACKSIZE
#undef YYMAXDEPTH
#define YYMAXDEPTH YYSTACKSIZE
#else
#ifdef YYMAXDEPTH
#define YYSTACKSIZE YYMAXDEPTH
#else
#define YYSTACKSIZE 10000
#define YYMAXDEPTH 10000
#endif
#endif
#define YYINITSTACKSIZE 200
int yydebug;
int yynerrs;
int yyerrflag;
int yychar;
short *yyssp;
YYSTYPE *yyvsp;
YYSTYPE yyval;
YYSTYPE yylval;
short *yyss;
short *yysslim;
YYSTYPE *yyvs;
int yystacksize;
#line 521 "ocl.y"
string progname = "ocl_Parse";

#define DEFAULT_TMPCHECK "screen.out"
#define DEFAULT_OUT_NAME "AST_tmp.py"

string default_out_path = "/home/moncs/wliang2/ATOM3_2.1/Proj/Ocl2Python/Prototype2/";

string usage = "usage: %s [oclSource] [tmpCheck]\n";

FILE *AST_out;

/* modified */
static PyObject *
ocl_Parse(PyObject *self, PyObject *args)
{
  string ocl_src = NULL;
  string tmpCheck = NULL;
  char path[255];


  string out_name = DEFAULT_OUT_NAME;
  string function_name = (string)strdup(DEFAULT_OUT_NAME);
  strcpy(path, default_out_path);
  strcat(path, out_name);

  /* parse the arguments recieved from python caller */
  if (! PyArg_Parse(args, "(s)", &ocl_src))
    return NULL;

	/*input from a file
  yyin = fopen(ocl_src, "r");
  assert(yyin);
	*/
	
	/* input from a string */
	oclSrc = ocl_src;

  if (tmpCheck == NULL)
    {
      tmpCheck = strdup(DEFAULT_TMPCHECK);
      yyout = fopen (tmpCheck, "w");
      assert(yyout);
    }

  /* start to creat python file for the AST in ATOM3 */

  /* remove ".py" from the function name */
  function_name[strlen(function_name) - 3] = '\0';

  AST_out = fopen(path, "w");
  assert(AST_out);

  /* print the header for all the neccessary import files */
  creat_imports();


  /* creat the initial environment */
  creat_init(function_name);

  /* start to parse the Ocl sourse file */
  yyparse();

  creat_end(function_name);

  /* done */
  fclose(AST_out);

  /* modified */
  Py_INCREF(Py_None);
  return Py_None;
}

static struct PyMethodDef ocl_methods[] = {
  {"ocl_Parse", ocl_Parse, 1},
  {NULL, NULL}
};

void initocl()
{
  (void) Py_InitModule("ocl", ocl_methods);
}

void
warning(string s, string t) /* print warning message */
{
  fprintf(stderr, "%s: %s", progname, s);
  if (t)
    fprintf(stderr, " %s", t);
  fprintf(stderr, " line %d\n", lineno);
}













































































#line 938 "y.tab.c"
/* allocate initial stack or double stack size, up to YYMAXDEPTH */
static int yygrowstack()
{
    int newsize, i;
    short *newss;
    YYSTYPE *newvs;

    if ((newsize = yystacksize) == 0)
        newsize = YYINITSTACKSIZE;
    else if (newsize >= YYMAXDEPTH)
        return -1;
    else if ((newsize *= 2) > YYMAXDEPTH)
        newsize = YYMAXDEPTH;
    i = yyssp - yyss;
    newss = yyss ? (short *)realloc(yyss, newsize * sizeof *newss) :
      (short *)malloc(newsize * sizeof *newss);
    if (newss == NULL)
        return -1;
    yyss = newss;
    yyssp = newss + i;
    newvs = yyvs ? (YYSTYPE *)realloc(yyvs, newsize * sizeof *newvs) :
      (YYSTYPE *)malloc(newsize * sizeof *newvs);
    if (newvs == NULL)
        return -1;
    yyvs = newvs;
    yyvsp = newvs + i;
    yystacksize = newsize;
    yysslim = yyss + newsize - 1;
    return 0;
}

#define YYABORT goto yyabort
#define YYREJECT goto yyabort
#define YYACCEPT goto yyaccept
#define YYERROR goto yyerrlab

#ifndef YYPARSE_PARAM
#if defined(__cplusplus) || __STDC__
#define YYPARSE_PARAM_ARG void
#define YYPARSE_PARAM_DECL
#else	/* ! ANSI-C/C++ */
#define YYPARSE_PARAM_ARG
#define YYPARSE_PARAM_DECL
#endif	/* ANSI-C/C++ */
#else	/* YYPARSE_PARAM */
#ifndef YYPARSE_PARAM_TYPE
#define YYPARSE_PARAM_TYPE void *
#endif
#if defined(__cplusplus) || __STDC__
#define YYPARSE_PARAM_ARG YYPARSE_PARAM_TYPE YYPARSE_PARAM
#define YYPARSE_PARAM_DECL
#else	/* ! ANSI-C/C++ */
#define YYPARSE_PARAM_ARG YYPARSE_PARAM
#define YYPARSE_PARAM_DECL YYPARSE_PARAM_TYPE YYPARSE_PARAM;
#endif	/* ANSI-C/C++ */
#endif	/* ! YYPARSE_PARAM */

int
yyparse (YYPARSE_PARAM_ARG)
    YYPARSE_PARAM_DECL
{
    register int yym, yyn, yystate;
#if YYDEBUG
    register const char *yys;

    if ((yys = getenv("YYDEBUG")))
    {
        yyn = *yys;
        if (yyn >= '0' && yyn <= '9')
            yydebug = yyn - '0';
    }
#endif

    yynerrs = 0;
    yyerrflag = 0;
    yychar = (-1);

    if (yyss == NULL && yygrowstack()) goto yyoverflow;
    yyssp = yyss;
    yyvsp = yyvs;
    *yyssp = yystate = 0;

yyloop:
    if ((yyn = yydefred[yystate])) goto yyreduce;
    if (yychar < 0)
    {
        if ((yychar = yylex()) < 0) yychar = 0;
#if YYDEBUG
        if (yydebug)
        {
            yys = 0;
            if (yychar <= YYMAXTOKEN) yys = yyname[yychar];
            if (!yys) yys = "illegal-symbol";
            printf("%sdebug: state %d, reading %d (%s)\n",
                    YYPREFIX, yystate, yychar, yys);
        }
#endif
    }
    if ((yyn = yysindex[yystate]) && (yyn += yychar) >= 0 &&
            yyn <= YYTABLESIZE && yycheck[yyn] == yychar)
    {
#if YYDEBUG
        if (yydebug)
            printf("%sdebug: state %d, shifting to state %d\n",
                    YYPREFIX, yystate, yytable[yyn]);
#endif
        if (yyssp >= yysslim && yygrowstack())
        {
            goto yyoverflow;
        }
        *++yyssp = yystate = yytable[yyn];
        *++yyvsp = yylval;
        yychar = (-1);
        if (yyerrflag > 0)  --yyerrflag;
        goto yyloop;
    }
    if ((yyn = yyrindex[yystate]) && (yyn += yychar) >= 0 &&
            yyn <= YYTABLESIZE && yycheck[yyn] == yychar)
    {
        yyn = yytable[yyn];
        goto yyreduce;
    }
    if (yyerrflag) goto yyinrecovery;
#if defined(lint) || defined(__GNUC__)
    goto yynewerror;
#endif
yynewerror:
    yyerror("syntax error");
#if defined(lint) || defined(__GNUC__)
    goto yyerrlab;
#endif
yyerrlab:
    ++yynerrs;
yyinrecovery:
    if (yyerrflag < 3)
    {
        yyerrflag = 3;
        for (;;)
        {
            if ((yyn = yysindex[*yyssp]) && (yyn += YYERRCODE) >= 0 &&
                    yyn <= YYTABLESIZE && yycheck[yyn] == YYERRCODE)
            {
#if YYDEBUG
                if (yydebug)
                    printf("%sdebug: state %d, error recovery shifting\
 to state %d\n", YYPREFIX, *yyssp, yytable[yyn]);
#endif
                if (yyssp >= yysslim && yygrowstack())
                {
                    goto yyoverflow;
                }
                *++yyssp = yystate = yytable[yyn];
                *++yyvsp = yylval;
                goto yyloop;
            }
            else
            {
#if YYDEBUG
                if (yydebug)
                    printf("%sdebug: error recovery discarding state %d\n",
                            YYPREFIX, *yyssp);
#endif
                if (yyssp <= yyss) goto yyabort;
                --yyssp;
                --yyvsp;
            }
        }
    }
    else
    {
        if (yychar == 0) goto yyabort;
#if YYDEBUG
        if (yydebug)
        {
            yys = 0;
            if (yychar <= YYMAXTOKEN) yys = yyname[yychar];
            if (!yys) yys = "illegal-symbol";
            printf("%sdebug: state %d, error recovery discards token %d (%s)\n",
                    YYPREFIX, yystate, yychar, yys);
        }
#endif
        yychar = (-1);
        goto yyloop;
    }
yyreduce:
#if YYDEBUG
    if (yydebug)
        printf("%sdebug: state %d, reducing by rule %d (%s)\n",
                YYPREFIX, yystate, yyn, yyrule[yyn]);
#endif
    yym = yylen[yyn];
    yyval = yyvsp[1-yym];
    switch (yyn)
    {
case 1:
#line 184 "ocl.y"
{ fprintf(yyout, "start\n"); /* setup the initial env of an expression */ }
break;
case 3:
#line 188 "ocl.y"
{ fprintf(yyout, "OclExpressions\nAt line: %d\n\n",lineno); }
break;
case 4:
#line 191 "ocl.y"
{ traverse(yyvsp[0].oclExpression, 0); }
break;
case 9:
#line 200 "ocl.y"
{ yyval.oclExpression=A_OclExpression(yyvsp[0].propertyCallExp,PROPERTYCALLEXP); fprintf(yyout, "PropertyCallExp\n"); }
break;
case 10:
#line 201 "ocl.y"
{ yyval.oclExpression=A_OclExpression(yyvsp[0].variableExp,VARIABLEEXP); fprintf(yyout, "VariableExp\n"); }
break;
case 11:
#line 202 "ocl.y"
{ yyval.oclExpression=A_OclExpression(yyvsp[0].literalExp,LITERALEXP); fprintf(yyout, "LiteralExp\n"); }
break;
case 12:
#line 203 "ocl.y"
{ yyval.oclExpression=A_OclExpression(yyvsp[0].letExp,LETEXP); fprintf(yyout, "LetExp\n"); }
break;
case 13:
#line 204 "ocl.y"
{ yyval.oclExpression=A_OclExpression(yyvsp[0].oclMessageExp,OCLMESSAGEEXP); fprintf(yyout, "OclMessageExp\n"); }
break;
case 14:
#line 205 "ocl.y"
{ yyval.oclExpression=A_OclExpression(yyvsp[0].ifExp,IFEXP); fprintf(yyout, "IfExp\n"); }
break;
case 15:
#line 206 "ocl.y"
{ yyval.oclExpression=yyvsp[-1].oclExpression; fprintf(yyout, "Parenthesized OclExpression\n"); }
break;
case 16:
#line 211 "ocl.y"
{ yyval.variableExp=A_VariableExp(yyvsp[0].pathName);
                      fprintf(yyout, "name\n");
                      /* Disambiguating rule
                       * name must be a name of a visible VaribleDeclaration in the current env */
                    }
break;
case 17:
#line 218 "ocl.y"
{ yyval.pathName = A_Name(yyvsp[0].sval,NULL); fprintf(yyout, "namestring\n"); }
break;
case 18:
#line 219 "ocl.y"
{ yyval.pathName = A_Name(yyvsp[-2].sval,yyvsp[0].pathName); fprintf(yyout, "name::namestring\n"); }
break;
case 19:
#line 224 "ocl.y"
{ yyval.literalExp=A_LiteralExp(yyvsp[0].enumLiteralExp,ENUMLITERALEXP); fprintf(yyout, "EnumLiteralExp\n"); }
break;
case 20:
#line 225 "ocl.y"
{ yyval.literalExp=A_LiteralExp(yyvsp[0].collectionLiteralExp,COLLECTIONLITERALEXP); fprintf(yyout, "CollectionLiteralExp\n"); }
break;
case 21:
#line 226 "ocl.y"
{ yyval.literalExp=A_LiteralExp(yyvsp[0].tupleLiteralExp,TUPLELITERALEXP); fprintf(yyout, "TupleLiteralExp\n"); }
break;
case 22:
#line 227 "ocl.y"
{ yyval.literalExp=A_LiteralExp(yyvsp[0].numericLiteralExp,NUMERICLITERALEXP); fprintf(yyout, "NumericLiteralExp\n"); }
break;
case 23:
#line 228 "ocl.y"
{ yyval.literalExp=A_LiteralExp(yyvsp[0].stringLiteralExp,STRINGLITERALEXP); fprintf(yyout, "StringLiteralExp\n"); }
break;
case 24:
#line 229 "ocl.y"
{ yyval.literalExp=A_LiteralExp(yyvsp[0].booleanLiteralExp,BOOLEANLITERALEXP); fprintf(yyout, "BooleanLiteralExp\n"); }
break;
case 25:
#line 233 "ocl.y"
{ yyval.enumLiteralExp=A_EnumLiteralExp(yyvsp[-2].pathName,yyvsp[0].sval); fprintf(yyout, "#name::namestring\n"); }
break;
case 26:
#line 239 "ocl.y"
{ yyval.collectionLiteralExp=A_CollectionLiteralExp(yyvsp[-3].collectionType,yyvsp[-1].collectionItem); fprintf(yyout, "CollectionTypeIdentifier '{' CollectionItemsPart '}'\n"); }
break;
case 27:
#line 242 "ocl.y"
{ fprintf(yyout, "CollectionTypeIdentifier:Set\n"); }
break;
case 28:
#line 243 "ocl.y"
{ fprintf(yyout, "CollectionTypeIdentifier:Bag\n"); }
break;
case 29:
#line 244 "ocl.y"
{ fprintf(yyout, "CollectionTypeIdentifier:Sequence\n"); }
break;
case 30:
#line 247 "ocl.y"
{ yyval.collectionItem = NULL; fprintf(yyout, "empty collection\n"); }
break;
case 31:
#line 248 "ocl.y"
{ yyval.collectionItem = yyvsp[0].collectionItem; }
break;
case 32:
#line 251 "ocl.y"
{ yyval.collectionItem=yyvsp[0].collectionItem; }
break;
case 33:
#line 252 "ocl.y"
{ yyval.collectionItem=A_CollectionItem_link(yyvsp[-2].collectionItem,yyvsp[0].collectionItem);
                                          fprintf(yyout, "CollectionItems , CollectionItem\n"); }
break;
case 34:
#line 256 "ocl.y"
{ yyval.collectionItem=A_CollectionItem(yyvsp[0].collectionRange,COLLECTIONRANGE); fprintf(yyout, "CollectionRange\n"); }
break;
case 35:
#line 257 "ocl.y"
{ yyval.collectionItem=A_CollectionItem(yyvsp[0].oclExpression,OCLEXPRESSION); fprintf(yyout, "IndividualItem\n"); }
break;
case 36:
#line 260 "ocl.y"
{ yyval.collectionRange=A_CollectionRange(yyvsp[-2].oclExpression,yyvsp[0].oclExpression); fprintf(yyout, "OclExp..OclExp\n"); }
break;
case 37:
#line 263 "ocl.y"
{ yyval.oclExpression=yyvsp[0].oclExpression; fprintf(yyout, "OclExp\n"); }
break;
case 38:
#line 268 "ocl.y"
{ yyval.numericLiteralExp=A_NumericLiteralExp(yyvsp[0].integerLiteralExp,INTEGERLITERALEXP);
                                         fprintf(yyout, "IntegerLiteralExp\n"); }
break;
case 39:
#line 270 "ocl.y"
{ yyval.numericLiteralExp=A_NumericLiteralExp(yyvsp[0].realLiteralExp,REALLITERALEXP); fprintf(yyout, "RealLiteralExp\n"); }
break;
case 40:
#line 273 "ocl.y"
{ yyval.integerLiteralExp=A_IntegerLiteralExp(yyvsp[0].ival); fprintf(yyout, "Integer\n"); }
break;
case 41:
#line 276 "ocl.y"
{ yyval.realLiteralExp=A_RealLiteralExp(yyvsp[0].dval); fprintf(yyout, "RealExp\n"); }
break;
case 42:
#line 280 "ocl.y"
{ yyval.stringLiteralExp=A_StringLiteralExp(yyvsp[0].sval); fprintf(yyout, "QStringlExp\n"); }
break;
case 43:
#line 284 "ocl.y"
{ yyval.booleanLiteralExp=A_BooleanLiteralExp(TRUE); fprintf(yyout, "true\n"); }
break;
case 44:
#line 285 "ocl.y"
{ yyval.booleanLiteralExp=A_BooleanLiteralExp(FALSE); fprintf(yyout, "false\n"); }
break;
case 45:
#line 290 "ocl.y"
{ yyval.tupleLiteralExp=A_TupleLiteralExp(yyvsp[-1].tupleLiteralExpParts);
                                                      fprintf(yyout, "TUPLE '{' non-empty TupleLiteralExpParts '}'\n"); }
break;
case 46:
#line 292 "ocl.y"
{ yyval.tupleLiteralExp=A_TupleLiteralExp(NULL); }
break;
case 47:
#line 295 "ocl.y"
{ yyval.tupleLiteralExpParts=A_TupleLiteralExpParts(yyvsp[0].variableDeclaration,NULL); }
break;
case 48:
#line 296 "ocl.y"
{ yyval.tupleLiteralExpParts=A_TupleLiteralExpParts(yyvsp[-2].variableDeclaration,yyvsp[0].tupleLiteralExpParts); }
break;
case 49:
#line 299 "ocl.y"
{ yyval.variableDeclaration=yyvsp[0].variableDeclaration; fprintf(yyout, "TupleLiteralExpPart\n"); }
break;
case 50:
#line 304 "ocl.y"
{ yyval.propertyCallExp=A_PropertyCallExp(yyvsp[0].modelPropertyCallExp,MODELPROPERTYCALLEXP);
                                          fprintf(yyout, "ModelPropertyCallExp\n"); }
break;
case 51:
#line 306 "ocl.y"
{ yyval.propertyCallExp=A_PropertyCallExp(yyvsp[0].loopExp,LOOPEXP); fprintf(yyout, "LoopExp\n"); }
break;
case 52:
#line 310 "ocl.y"
{ yyval.loopExp=A_LoopExp(yyvsp[0].iteratorExp,ITERATOREXP); fprintf(yyout, "IteratorExp\n"); }
break;
case 53:
#line 311 "ocl.y"
{ yyval.loopExp=A_LoopExp(yyvsp[0].iterateExp,ITERATEEXP); fprintf(yyout, "IterateExp\n"); }
break;
case 54:
#line 316 "ocl.y"
{ yyval.iteratorExp=A_IteratorExp(yyvsp[-7].oclExpression,yyvsp[-5].collectionOp,yyvsp[-3].variableDeclaration,yyvsp[-1].oclExpression); }
break;
case 55:
#line 321 "ocl.y"
{ yyval.iterateExp=A_IterateExp(yyvsp[-9].oclExpression,yyvsp[-5].variableDeclaration,yyvsp[-3].variableDeclaration,yyvsp[-1].oclExpression); }
break;
case 56:
#line 326 "ocl.y"
{ yyval.collectionOp=A_SELECT; fprintf(yyout, "select\n"); }
break;
case 57:
#line 327 "ocl.y"
{ yyval.collectionOp=A_COLLECT; fprintf(yyout, "collect\n"); }
break;
case 58:
#line 328 "ocl.y"
{ yyval.collectionOp=A_REJECT; fprintf(yyout, "reject\n"); }
break;
case 59:
#line 329 "ocl.y"
{ yyval.collectionOp=A_FORALL; fprintf(yyout, "forAll\n"); }
break;
case 60:
#line 330 "ocl.y"
{ yyval.collectionOp=A_EXISTS; fprintf(yyout, "exists\n"); }
break;
case 61:
#line 331 "ocl.y"
{ yyval.collectionOp=A_ISUNIQUE; fprintf(yyout, "isUnique\n"); }
break;
case 62:
#line 332 "ocl.y"
{ yyval.collectionOp=A_SIZE; fprintf(yyout, "size\n"); }
break;
case 63:
#line 333 "ocl.y"
{ yyval.collectionOp=A_ISEMPTY; fprintf(yyout, "isEmpty\n"); }
break;
case 64:
#line 334 "ocl.y"
{ yyval.collectionOp=A_NOTEMPTY; fprintf(yyout, "notEmpty\n"); }
break;
case 65:
#line 335 "ocl.y"
{ yyval.collectionOp=A_COUNT; fprintf(yyout, "count\n"); }
break;
case 66:
#line 336 "ocl.y"
{ yyval.collectionOp=A_UNION; fprintf(yyout, "union\n"); }
break;
case 67:
#line 337 "ocl.y"
{ yyval.collectionOp=A_DIFFERENCE; fprintf(yyout, "difference\n"); }
break;
case 68:
#line 340 "ocl.y"
{ yyval.variableDeclaration=NULL; fprintf(yyout, "default iterator\n"); }
break;
case 69:
#line 341 "ocl.y"
{ yyval.variableDeclaration=yyvsp[0].variableDeclaration; fprintf(yyout, "iterator is a VariableDeclaration\n"); }
break;
case 70:
#line 344 "ocl.y"
{ yyval.variableDeclaration=yyvsp[0].variableDeclaration; fprintf(yyout, "result is a VariableDeclaration\n"); }
break;
case 71:
#line 349 "ocl.y"
{ yyval.variableDeclaration=A_VariableDeclaration(yyvsp[-4].sval,yyvsp[-2].pathName,yyvsp[0].oclExpression);
      fprintf(yyout, "VariableDeclaration with type and initExpression\n"); }
break;
case 72:
#line 351 "ocl.y"
{ yyval.variableDeclaration=A_VariableDeclaration(yyvsp[-2].sval,yyvsp[0].pathName,NULL);
                        fprintf(yyout, "VariableDeclaration with type but not initExpression\n"); }
break;
case 73:
#line 353 "ocl.y"
{ yyval.variableDeclaration=A_VariableDeclaration(yyvsp[0].sval,NULL,NULL);
               fprintf(yyout, "VariableDeclaration without type nor initExpression\n"); }
break;
case 74:
#line 357 "ocl.y"
{ yyval.sval=yyvsp[0].sval; fprintf(yyout, "VarName is %s\n", yyvsp[0].sval); }
break;
case 75:
#line 360 "ocl.y"
{ yyval.pathName=yyvsp[0].pathName; fprintf(yyout, "type is \n"); }
break;
case 76:
#line 363 "ocl.y"
{ yyval.oclExpression=yyvsp[0].oclExpression; fprintf(yyout, "initExpression\n"); }
break;
case 77:
#line 368 "ocl.y"
{ yyval.modelPropertyCallExp=A_ModelPropertyCallExp(yyvsp[0].operationCallExp,OPERATIONCALLEXP);
                                          fprintf(yyout, "OperationCallExp\n"); }
break;
case 78:
#line 370 "ocl.y"
{ yyval.modelPropertyCallExp=A_ModelPropertyCallExp(yyvsp[0].attrOrNavCallExp,ATTRORNAVCALLEXP);
                        fprintf(yyout, "AttributeCallExp or NavigationCallExp\n"); }
break;
case 79:
#line 378 "ocl.y"
{ yyval.operationCallExp=A_OperationCallExp(yyvsp[-2].oclExpression,"PLUS",FALSE,A_Arguments(yyvsp[0].oclExpression,NULL));
                                                      fprintf(yyout, "PLUS operation\n"); }
break;
case 80:
#line 380 "ocl.y"
{ yyval.operationCallExp=A_OperationCallExp(yyvsp[-2].oclExpression,"MINUS",FALSE,A_Arguments(yyvsp[0].oclExpression,NULL));
                                         fprintf(yyout, "MINUS operation\n"); }
break;
case 81:
#line 382 "ocl.y"
{ yyval.operationCallExp=A_OperationCallExp(yyvsp[-2].oclExpression,"TIMES",FALSE,A_Arguments(yyvsp[0].oclExpression,NULL));
                                         fprintf(yyout, "TIMES operation\n"); }
break;
case 82:
#line 384 "ocl.y"
{ yyval.operationCallExp=A_OperationCallExp(yyvsp[-2].oclExpression,"DIVIDES",FALSE,A_Arguments(yyvsp[0].oclExpression,NULL));
                                           fprintf(yyout, "DIVIDES operation\n"); }
break;
case 83:
#line 386 "ocl.y"
{ yyval.operationCallExp=A_OperationCallExp(yyvsp[-2].oclExpression,"AND",FALSE,A_Arguments(yyvsp[0].oclExpression,NULL));
                                       fprintf(yyout, "AND operation\n"); }
break;
case 84:
#line 388 "ocl.y"
{ yyval.operationCallExp=A_OperationCallExp(yyvsp[-2].oclExpression,"OR",FALSE,A_Arguments(yyvsp[0].oclExpression,NULL));
                                      fprintf(yyout, "OR operation\n"); }
break;
case 85:
#line 390 "ocl.y"
{ yyval.operationCallExp=A_OperationCallExp(yyvsp[-2].oclExpression,"XOR",FALSE,A_Arguments(yyvsp[0].oclExpression,NULL));
                                       fprintf(yyout, "XOR operation\n"); }
break;
case 86:
#line 392 "ocl.y"
{ yyval.operationCallExp=A_OperationCallExp(yyvsp[-2].oclExpression,"EQ",FALSE,A_Arguments(yyvsp[0].oclExpression,NULL));
                                      fprintf(yyout, "EQ operation\n"); }
break;
case 87:
#line 394 "ocl.y"
{ yyval.operationCallExp=A_OperationCallExp(yyvsp[-2].oclExpression,"NOTEQ",FALSE,A_Arguments(yyvsp[0].oclExpression,NULL));
                                        fprintf(yyout, "NOTEQ operation\n"); }
break;
case 88:
#line 396 "ocl.y"
{ yyval.operationCallExp=A_OperationCallExp(yyvsp[-2].oclExpression,"LTEQ",FALSE,A_Arguments(yyvsp[0].oclExpression,NULL));
                                        fprintf(yyout, "MLTEQ operation\n"); }
break;
case 89:
#line 398 "ocl.y"
{ yyval.operationCallExp=A_OperationCallExp(yyvsp[-2].oclExpression,"GTEQ",FALSE,A_Arguments(yyvsp[0].oclExpression,NULL));
                                        fprintf(yyout, "GTEQ operation\n"); }
break;
case 90:
#line 400 "ocl.y"
{ yyval.operationCallExp=A_OperationCallExp(yyvsp[-2].oclExpression,"LT",FALSE,A_Arguments(yyvsp[0].oclExpression,NULL));
                                      fprintf(yyout, "LT operation\n"); }
break;
case 91:
#line 402 "ocl.y"
{ yyval.operationCallExp=A_OperationCallExp(yyvsp[-2].oclExpression,"GT",FALSE,A_Arguments(yyvsp[0].oclExpression,NULL));
                                      fprintf(yyout, "GT operation\n"); }
break;
case 92:
#line 404 "ocl.y"
{ yyval.operationCallExp=A_OperationCallExp(yyvsp[-2].oclExpression,"IMPLIES",FALSE,A_Arguments(yyvsp[0].oclExpression,NULL));
                                           fprintf(yyout, "IMPLIES operation\n"); }
break;
case 93:
#line 407 "ocl.y"
{ yyval.operationCallExp=A_OperationCallExp(yyvsp[-6].oclExpression,yyvsp[-4].sval,yyvsp[-3].bval,yyvsp[-1].args);
        fprintf(yyout, "model operation\n"); }
break;
case 94:
#line 409 "ocl.y"
{ /*$$=A_OperationCallExp(NULL,$1,$2,$4);
						       fprintf(yyout, "model operation with default source\n");*/
                                                     warning("The source of the mdlPropertyCall must be specified\n",NULL); exit(1);}
break;
case 95:
#line 412 "ocl.y"
{ yyval.operationCallExp=A_OperationCallExp(yyvsp[0].oclExpression,"NOT",FALSE,NULL);
                         fprintf(yyout, "negates operation\n"); }
break;
case 96:
#line 416 "ocl.y"
{ yyval.bval=FALSE; }
break;
case 97:
#line 417 "ocl.y"
{ yyval.bval=TRUE; fprintf(yyout, "at Pre\n"); }
break;
case 98:
#line 420 "ocl.y"
{ yyval.args=NULL; fprintf(yyout, "empty argument\n"); }
break;
case 99:
#line 421 "ocl.y"
{ yyval.args=yyvsp[0].args; fprintf(yyout, "non empty argumentsn\n"); }
break;
case 100:
#line 425 "ocl.y"
{ yyval.oclExpression=yyvsp[0].oclExpression; fprintf(yyout, "argument\n"); }
break;
case 101:
#line 428 "ocl.y"
{ yyval.args=A_Arguments(yyvsp[0].oclExpression, NULL); }
break;
case 102:
#line 429 "ocl.y"
{ yyval.args=A_Arguments(yyvsp[-2].oclExpression, yyvsp[0].args); }
break;
case 103:
#line 433 "ocl.y"
{ fprintf(yyout, "body\n"); }
break;
case 104:
#line 436 "ocl.y"
{ yyval.sval=yyvsp[0].sval; fprintf(yyout, "mdlProperty: %s\n", yyvsp[0].sval); }
break;
case 105:
#line 446 "ocl.y"
{ yyval.attrOrNavCallExp=A_AttrOrNavCallExp(yyvsp[-3].oclExpression,yyvsp[-1].sval,yyvsp[0].bval); fprintf(yyout, "AttrOrNavCallExp with source\n"); }
break;
case 106:
#line 454 "ocl.y"
{ yyval.letExp=A_LetExp(yyvsp[-1].vars,yyvsp[0].oclExpression); }
break;
case 107:
#line 457 "ocl.y"
{ yyval.vars=A_Variables(yyvsp[-1].variableDeclaration,NULL); }
break;
case 108:
#line 458 "ocl.y"
{ yyval.vars=A_Variables(yyvsp[-2].variableDeclaration,yyvsp[0].vars); fprintf(yyout, "multi-var def\n"); }
break;
case 109:
#line 461 "ocl.y"
{ yyval.variableDeclaration=yyvsp[0].variableDeclaration; }
break;
case 110:
#line 465 "ocl.y"
{ yyval.variableDeclaration=A_VariableDeclaration(yyvsp[-4].sval,yyvsp[-2].pathName,yyvsp[0].oclExpression);
      fprintf(yyout, "variableDeclarationInLetExp with type and initExpression\n"); }
break;
case 111:
#line 469 "ocl.y"
{ yyval.oclExpression=yyvsp[0].oclExpression; fprintf(yyout, "LetExpSub\n"); }
break;
case 112:
#line 475 "ocl.y"
{ yyval.oclExpression=yyvsp[-1].oclExpression; fprintf(yyout, "scope of the let expr\n"); }
break;
case 113:
#line 483 "ocl.y"
{ yyval.oclMessageExp = A_OclMessageExp(yyvsp[-5].oclExpression, yyvsp[-3].sval, yyvsp[-1].oclMessageArg); }
break;
case 114:
#line 486 "ocl.y"
{ yyval.oclMessageArg=NULL; fprintf(yyout, "no args\n"); }
break;
case 115:
#line 487 "ocl.y"
{ yyval.oclMessageArg=yyvsp[0].oclMessageArg; fprintf(yyout, "OclMsgArg\n"); }
break;
case 116:
#line 490 "ocl.y"
{ yyval.oclMessageArg=yyvsp[0].oclMessageArg; }
break;
case 117:
#line 491 "ocl.y"
{ yyval.oclMessageArg=A_OclMessageArg_link(yyvsp[-2].oclMessageArg,yyvsp[0].oclMessageArg); }
break;
case 118:
#line 494 "ocl.y"
{ yyval.oclMessageArg=A_OclMessageArg(A_UnspecifiedValueExp(NULL),UNSPECIFIEDVALUEEXP); }
break;
case 119:
#line 495 "ocl.y"
{ yyval.oclMessageArg=A_OclMessageArg(A_UnspecifiedValueExp(yyvsp[0].pathName),UNSPECIFIEDVALUEEXP); }
break;
case 120:
#line 496 "ocl.y"
{ yyval.oclMessageArg=A_OclMessageArg(yyvsp[0].oclExpression,OCLEXPRESSION); }
break;
case 121:
#line 503 "ocl.y"
{ yyval.ifExp = A_IfExp(yyvsp[-5].oclExpression, yyvsp[-3].oclExpression, yyvsp[-1].oclExpression); }
break;
case 122:
#line 506 "ocl.y"
{ yyval.oclExpression = yyvsp[0].oclExpression; }
break;
case 123:
#line 509 "ocl.y"
{ yyval.oclExpression = yyvsp[0].oclExpression; }
break;
case 124:
#line 512 "ocl.y"
{ yyval.oclExpression = yyvsp[0].oclExpression; }
break;
#line 1641 "y.tab.c"
    }
    yyssp -= yym;
    yystate = *yyssp;
    yyvsp -= yym;
    yym = yylhs[yyn];
    if (yystate == 0 && yym == 0)
    {
#if YYDEBUG
        if (yydebug)
            printf("%sdebug: after reduction, shifting from state 0 to\
 state %d\n", YYPREFIX, YYFINAL);
#endif
        yystate = YYFINAL;
        *++yyssp = YYFINAL;
        *++yyvsp = yyval;
        if (yychar < 0)
        {
            if ((yychar = yylex()) < 0) yychar = 0;
#if YYDEBUG
            if (yydebug)
            {
                yys = 0;
                if (yychar <= YYMAXTOKEN) yys = yyname[yychar];
                if (!yys) yys = "illegal-symbol";
                printf("%sdebug: state %d, reading %d (%s)\n",
                        YYPREFIX, YYFINAL, yychar, yys);
            }
#endif
        }
        if (yychar == 0) goto yyaccept;
        goto yyloop;
    }
    if ((yyn = yygindex[yym]) && (yyn += yystate) >= 0 &&
            yyn <= YYTABLESIZE && yycheck[yyn] == yystate)
        yystate = yytable[yyn];
    else
        yystate = yydgoto[yym];
#if YYDEBUG
    if (yydebug)
        printf("%sdebug: after reduction, shifting from state %d \
to state %d\n", YYPREFIX, *yyssp, yystate);
#endif
    if (yyssp >= yysslim && yygrowstack())
    {
        goto yyoverflow;
    }
    *++yyssp = yystate;
    *++yyvsp = yyval;
    goto yyloop;
yyoverflow:
    yyerror("yacc stack overflow");
yyabort:
    return (1);
yyaccept:
    return (0);
}
